
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (size_t) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 82
#define YY_END_OF_BUFFER 83
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[636] =
    {   0,
        0,    0,   81,   81,    0,    0,   83,   80,   78,   79,
       69,   75,   77,   76,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   80,   80,   80,   80,
       80,   80,   80,   68,   67,   81,   82,   73,   72,   74,
       82,   78,   75,   76,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   81,   73,   71,   70,    0,   19,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   12,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   65,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   53,    0,    0,    0,
        0,    0,    4,    0,    0,    0,    0,    8,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    5,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    2,
        0,   46,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   45,    1,    0,    0,    0,    0,   23,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   22,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   13,    0,   20,    0,   54,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   14,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   15,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   26,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   61,    0,
        0,    0,   31,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    7,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   51,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   60,    0,    0,
        0,    0,    0,    0,    0,    0,   63,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    9,
        3,    0,    0,   30,    0,   58,    0,    0,    0,   24,
       33,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   37,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   41,    0,    0,    0,    0,
        0,    0,    0,   25,    0,   47,   21,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       34,    0,    0,    0,    0,    0,    0,    0,    0,   48,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   59,   28,    0,    0,    0,    0,    0,

        0,   17,    0,   50,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   49,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   36,    0,   52,    0,   35,
       16,    0,    0,    0,    0,    0,    6,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   18,
        0,    0,    0,    0,    0,    0,    0,   64,   56,   29,
       32,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   62,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   27,    0,    0,    0,   55,

       42,   43,   66,    0,   10,    0,    0,    0,    0,   40,
        0,    0,    0,    0,    0,   44,    0,    0,    0,    0,
        0,    0,    0,   57,    0,    0,    0,    0,    0,    0,
        0,   11,   39,   38,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    6,    1,    1,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    8,    1,    1,    1,    1,    9,   10,   11,   12,

       13,   14,   15,   16,   17,    1,   18,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
       32,    1,   33,   34,   35,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[36] =
    {   0,
        1,    2,    3,    4,    2,    1,    1,    4,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[642] =
    {   0,
        0,    0,   34,   38,   41,   43,  658,  659,  655,  659,
      659,    0,  659,  649,   36,   35,   29,   47,   41,   49,
      642,  633,  640,  635,   33,  629,  629,   56,  621,   60,
      635,   54,   61,  659,  659,    0,  659,    0,  659,  659,
      644,  644,    0,  638,  632,  624,  619,   56,  620,  628,
       58,  612,  625,  610,   72,  619,  607,  625,  614,   64,
      607,  609,  621,   76,   70,  619,   63,  609,   65,  621,
      599,  619,  611,  593,   87,   85,  591,  615,  592,  600,
      593,    0,    0,  659,  659,  611,  594,  602,  597,  607,
      603,  579,  591,  592,  595,  598,   88,  578,  596,  593,

      576,  582,  590,  574,  580,  585,  577,  576,  583,  581,
      562,  565,  563,  577,  566,  659,  575,  568,  575,  579,
      557,  560,  565,  570,  564,  560,  553,  659,  565,  557,
      547,  547,  561,  563,  565,  543,  560,  555,  539,  539,
      556,  534,  542,  535,  547,  535,  659,  532,  537,  542,
      529,  545,  659,  539,  525,  527,  545,  537,  522,  535,
      535,  534,  536,  538,  530,  511,  532,  523,  512,  523,
      531,  505,  529,  518,  510,  515,  522,  516,  513,  659,
      511,  495,  520,  493,  507,  498,  516,  496,  506,  493,
      506,  659,  504,  488,  487,  508,  501,  506,  492,  478,

      492,  495,  485,  493,  496,  498,  484,  485,  479,  475,
      493,  659,  472,  491,  469,  486,  469,  659,  482,  483,
      485,  477,  480,  475,  473,  469,  460,   94,  473,  451,
      473,  455,  474,  457,  472,  452,  459,  449,  465,  456,
      459,  459,  444,  460,  456,  458,  460,  438,  455,  457,
      441,  435,  435,  453,  432,  437,  429,  432,  433,  444,
      427,  659,  442,  659,  438,  659,  422,  429,  435,  421,
      426,  433,  421,  421,  415,  427,  418,  425,  424,  430,
      414,  407,  421,  411,  404,  417,  418,  400,  400,  413,
      416,  399,  659,  404,  405,  400,  393,  394,  403,  400,

      410,  389,  382,  402,  399,  389,  659,  383,  390,  381,
      394,  394,  393,  398,  397,  389,  659,  382,  388,  374,
      383,  391,  375,  367,  363,  367,  383,  376,  659,  377,
      370,  366,  381,  359,  375,  362,  364,  357,  368,  374,
      352,  346,  355,  367,  349,  353,  352,  366,  365,  361,
      363,  356,  350,  334,  352,  349,  351,  337,  336,  347,
      345,  352,  340,  336,  659,  338,  326,  333,  325,  345,
      340,  336,  334,  315,  659,  335,  332,  324,  318,  330,
      330,  314,  325,  332,  331,  330,  318,  659,  322,  324,
       92,  320,  304,  313,  316,  306,  659,  315,  313,  300,

      311,  310,  301,  312,  295,  294,  309,  296,  296,  659,
      659,  298,  292,  659,  304,  659,  296,  299,  293,  283,
      659,  292,  281,  284,  278,  275,  289,  283,  288,  280,
      290,  285,  280,  283,  274,  659,  273,  287,  261,  278,
      264,  274,  261,  259,  273,  659,  258,  278,  270,  261,
      253,  252,  270,  659,  251,  659,  659,  264,  251,  250,
      265,  256,  266,  240,  257,  237,  255,  242,  251,  251,
      659,  247,  240,  236,  235,  247,  234,  239,  246,  659,
      242,  230,  248,  226,  233,  230,  223,  223,  228,  238,
      227,  232,  230,  659,  659,  237,  224,  235,  218,  217,

      217,  659,  211,  659,  205,  203,  207,  220,  215,  222,
      213,  223,  201,  212,  213,  659,  216,  207,  195,  203,
      199,  204,  213,  195,  192,  659,  210,  659,  192,  659,
      659,  197,  200,  185,  190,  197,  659,  196,  183,  180,
      187,  192,  192,  178,  180,  189,  187,  167,  184,  659,
      168,  177,  182,  182,  162,  186,  185,  659,  659,  659,
      659,  170,  161,  179,  162,  180,  168,  171,  171,  170,
      168,  157,  154,  169,  168,  151,  143,  154,  161,  153,
      159,  659,  164,  138,  151,  154,  155,  138,  138,  137,
      129,  137,  138,   44,   68,  659,   80,  100,   96,  659,

      659,  659,  659,   90,  659,  100,   96,  105,   93,  659,
       94,  110,  118,  113,  104,  659,  118,  114,  123,  109,
      119,  115,  110,  659,  121,  116,  111,  112,  125,  113,
      114,  659,  659,  659,  659,  140,  144,  148,  152,  156,
      158
    } ;

static yyconst flex_int16_t yy_def[642] =
    {   0,
      635,    1,  636,  636,  637,  637,  635,  635,  635,  635,
      635,  638,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  639,  635,  640,  635,  635,
      641,  635,  638,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  639,  640,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,

      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,    0,  635,  635,  635,  635,  635,
      635
    } ;

static yyconst flex_int16_t yy_nxt[695] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,    8,   15,   16,
       17,   18,   19,   20,    8,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   31,   32,    8,   33,    8,
        8,    8,   34,   35,   34,   37,   37,   52,   37,   37,
       37,   67,   37,   39,   40,   39,   40,   45,   41,  606,
       41,   49,   56,   53,   46,   54,   50,   59,   47,   55,
       68,   57,   51,   48,   71,   60,   77,   89,   74,   80,
       61,   58,   75,   62,   93,   78,  105,   81,   79,  118,
       72,   98,  115,   94,  607,   99,   90,  110,  111,  119,
      122,  123,  112,  120,  106,  129,  152,  100,  113,  276,

      153,  116,  114,  431,  608,  133,  277,  134,  609,  130,
      131,  135,  132,  610,  611,  612,  613,  614,  615,  616,
      278,  432,  617,  618,  619,  620,  621,  622,  623,  624,
      625,  626,  627,  628,  629,  630,  631,  632,  633,  634,
       36,   36,   36,   36,   38,   38,   38,   38,   43,   43,
      605,   43,   82,  604,  603,   82,   83,   83,   84,   84,
       84,   84,  602,  601,  600,  599,  598,  597,  596,  595,
      594,  593,  592,  591,  590,  589,  588,  587,  586,  585,
      584,  583,  582,  581,  580,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  569,  568,  567,  566,  565,

      564,  563,  562,  561,  560,  559,  558,  557,  556,  555,
      554,  553,  552,  551,  550,  549,  548,  547,  546,  545,
      544,  543,  542,  541,  540,  539,  538,  537,  536,  535,
      534,  533,  532,  531,  530,  529,  528,  527,  526,  525,
      524,  523,  522,  521,  520,  519,  518,  517,  516,  515,
      514,  513,  512,  511,  510,  509,  508,  507,  506,  505,
      504,  503,  502,  501,  500,  499,  498,  497,  496,  495,
      494,  493,  492,  491,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  481,  480,  479,  478,  477,  476,  475,
      474,  473,  472,  471,  470,  469,  468,  467,  466,  465,

      464,  463,  462,  461,  460,  459,  458,  457,  456,  455,
      454,  453,  452,  451,  450,  449,  448,  447,  446,  445,
      444,  443,  442,  441,  440,  439,  438,  437,  436,  435,
      434,  433,  430,  429,  428,  427,  426,  425,  424,  423,
      422,  421,  420,  419,  418,  417,  416,  415,  414,  413,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  403,
      402,  401,  400,  399,  398,  397,  396,  395,  394,  393,
      392,  391,  390,  389,  388,  387,  386,  385,  384,  383,
      382,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  364,  363,

      362,  361,  360,  359,  358,  357,  356,  355,  354,  353,
      352,  351,  350,  349,  348,  347,  346,  345,  344,  343,
      342,  341,  340,  339,  338,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
      322,  321,  320,  319,  318,  317,  316,  315,  314,  313,
      312,  311,  310,  309,  308,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  296,  295,  294,  293,
      292,  291,  290,  289,  288,  287,  286,  285,  284,  283,
      282,  281,  280,  279,  275,  274,  273,  272,  271,  270,
      269,  268,  267,  266,  265,  264,  263,  262,  261,  260,

      259,  258,  257,  256,  255,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  245,  244,  243,  242,  241,  240,
      239,  238,  237,  236,  235,  234,  233,  232,  231,  230,
      229,  228,  227,  226,  225,  224,  223,  222,  221,  220,
      219,  218,  217,  216,  215,  214,  213,  212,  211,  210,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  191,  190,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  180,
      179,  178,  177,  176,  175,  174,  173,  172,  171,  170,
      169,  168,  167,  166,  165,  164,  163,  162,  161,  160,

      159,  158,  157,  156,  155,  154,  151,  150,  149,  148,
      147,  146,  145,  144,  143,  142,  141,  140,  139,  138,
      137,  136,  128,  127,  126,  125,  124,  121,  117,  109,
      108,  107,  104,  103,  102,  101,   97,   96,   95,   92,
       91,   88,   87,   86,   44,   42,   85,   76,   73,   70,
       69,   66,   65,   64,   63,   44,   42,  635,    7,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635

    } ;

static yyconst flex_int16_t yy_chk[695] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,   17,    3,    4,
        4,   25,    4,    5,    5,    6,    6,   15,    5,  594,
        6,   16,   19,   17,   15,   18,   16,   20,   15,   18,
       25,   19,   16,   15,   28,   20,   32,   48,   30,   33,
       20,   19,   30,   20,   51,   32,   60,   33,   32,   67,
       28,   55,   65,   51,  595,   55,   48,   64,   64,   67,
       69,   69,   64,   67,   60,   75,   97,   55,   64,  228,

       97,   65,   64,  391,  597,   76,  228,   76,  598,   75,
       75,   76,   75,  599,  604,  606,  607,  608,  609,  611,
      228,  391,  612,  613,  614,  615,  617,  618,  619,  620,
      621,  622,  623,  625,  626,  627,  628,  629,  630,  631,
      636,  636,  636,  636,  637,  637,  637,  637,  638,  638,
      593,  638,  639,  592,  591,  639,  640,  640,  641,  641,
      641,  641,  590,  589,  588,  587,  586,  585,  584,  583,
      581,  580,  579,  578,  577,  576,  575,  574,  573,  572,
      571,  570,  569,  568,  567,  566,  565,  564,  563,  562,
      557,  556,  555,  554,  553,  552,  551,  549,  548,  547,

      546,  545,  544,  543,  542,  541,  540,  539,  538,  536,
      535,  534,  533,  532,  529,  527,  525,  524,  523,  522,
      521,  520,  519,  518,  517,  515,  514,  513,  512,  511,
      510,  509,  508,  507,  506,  505,  503,  501,  500,  499,
      498,  497,  496,  493,  492,  491,  490,  489,  488,  487,
      486,  485,  484,  483,  482,  481,  479,  478,  477,  476,
      475,  474,  473,  472,  470,  469,  468,  467,  466,  465,
      464,  463,  462,  461,  460,  459,  458,  455,  453,  452,
      451,  450,  449,  448,  447,  445,  444,  443,  442,  441,
      440,  439,  438,  437,  435,  434,  433,  432,  431,  430,

      429,  428,  427,  426,  425,  424,  423,  422,  420,  419,
      418,  417,  415,  413,  412,  409,  408,  407,  406,  405,
      404,  403,  402,  401,  400,  399,  398,  396,  395,  394,
      393,  392,  390,  389,  387,  386,  385,  384,  383,  382,
      381,  380,  379,  378,  377,  376,  374,  373,  372,  371,
      370,  369,  368,  367,  366,  364,  363,  362,  361,  360,
      359,  358,  357,  356,  355,  354,  353,  352,  351,  350,
      349,  348,  347,  346,  345,  344,  343,  342,  341,  340,
      339,  338,  337,  336,  335,  334,  333,  332,  331,  330,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  319,

      318,  316,  315,  314,  313,  312,  311,  310,  309,  308,
      306,  305,  304,  303,  302,  301,  300,  299,  298,  297,
      296,  295,  294,  292,  291,  290,  289,  288,  287,  286,
      285,  284,  283,  282,  281,  280,  279,  278,  277,  276,
      275,  274,  273,  272,  271,  270,  269,  268,  267,  265,
      263,  261,  260,  259,  258,  257,  256,  255,  254,  253,
      252,  251,  250,  249,  248,  247,  246,  245,  244,  243,
      242,  241,  240,  239,  238,  237,  236,  235,  234,  233,
      232,  231,  230,  229,  227,  226,  225,  224,  223,  222,
      221,  220,  219,  217,  216,  215,  214,  213,  211,  210,

      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  191,  190,  189,
      188,  187,  186,  185,  184,  183,  182,  181,  179,  178,
      177,  176,  175,  174,  173,  172,  171,  170,  169,  168,
      167,  166,  165,  164,  163,  162,  161,  160,  159,  158,
      157,  156,  155,  154,  152,  151,  150,  149,  148,  146,
      145,  144,  143,  142,  141,  140,  139,  138,  137,  136,
      135,  134,  133,  132,  131,  130,  129,  127,  126,  125,
      124,  123,  122,  121,  120,  119,  118,  117,  115,  114,
      113,  112,  111,  110,  109,  108,  107,  106,  105,  104,

      103,  102,  101,  100,   99,   98,   96,   95,   94,   93,
       92,   91,   90,   89,   88,   87,   86,   81,   80,   79,
       78,   77,   74,   73,   72,   71,   70,   68,   66,   63,
       62,   61,   59,   58,   57,   56,   54,   53,   52,   50,
       49,   47,   46,   45,   44,   42,   41,   31,   29,   27,
       26,   24,   23,   22,   21,   14,    9,    7,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635,  635,  635,  635,  635,  635,  635,
      635,  635,  635,  635

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "./fconfigl.l"
#line 2 "./fconfigl.l"
#include "gnats.h"
#include "fconfig.h"

#define YY_INPUT(buf, result, max_size) { \
  extern int (*yyinpfunc)(char *, int); \
  result = (yyinpfunc)((buf), (max_size)); \
}

int fconfig_lineno;

static struct qstring {
  char *str;
  struct qstring *prev, *next;
} *qstringList;

char *
qStrVal (struct qstring *str)
{
  return str->str;
}

char *
takeQString (struct qstring *str)
{
  char *res = str->str;
  if (str->prev != NULL)
    {
      str->prev->next = str->next;
    }
  else
    {
      qstringList = str->next;
    }
  if (str->next != NULL)
    {
      str->next->prev = (str->prev);
    }
  free (str);
  return res;
}

void
cleanLexer (void)
{
  struct qstring *p = qstringList;

  while (p != NULL)
    {
      struct qstring *next = p->next;
      free (p->str);
      free (p);
      p = next;
    }
  qstringList = NULL;
}

/* This is pretty crummy. */
static struct qstring *
lexQString (char *str) 
{
  int len = strlen (str) - 1;
  char *dest;
  int z;
  struct qstring *res = (struct qstring *) xmalloc (sizeof (struct qstring));
  res->str = xmalloc (len + 1);
  dest = res->str;

  if (qstringList == NULL)
    {
      res->next = NULL;
      res->prev = NULL;
    }
  else
    {
      res->next = qstringList;
      qstringList->prev = res;
      res->prev = NULL;
    }
  qstringList = res;

  for (z = 0; z < len; z++)
    {
      if (str[z] == '\\')
	{
	  z++;
	  if (z < len)
	    {
	      switch (str[z])
		{
		case '\n':
		  break;
		case 'n':
		  *(dest++) = '\n';
		  break;
		case 't':
		  *(dest++) = '\t';
		  break;
		case 'r':
		  *(dest++) = '\r';
		  break;
		case '"':
		  *(dest++) = '"';
		  break;
		case '\\':
		  *(dest++) = '\\';
		  break;
		default:
		  *(dest++) = '\\';
		  *(dest++) = str[z];
		  break;
		}
	    }
	}
      else
	{
	  *(dest++) = str[z];
	}
    }
  *(dest) = '\0';
  return res;
}



#line 934 "<stdout>"

#define INITIAL 0
#define BadTok 1
#define QuoteLex 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 131 "./fconfigl.l"

#line 1087 "<stdout>"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (yy_c_buf_p) - (yytext_ptr);
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 636 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 659 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 132 "./fconfigl.l"
{
  return FIELD;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 136 "./fconfigl.l"
{
  return STRINGTYPE;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 140 "./fconfigl.l"
{
  return MULTITEXTTYPE;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 144 "./fconfigl.l"
{
  return DATETYPE;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 148 "./fconfigl.l"
{
  return PATHTOK;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 152 "./fconfigl.l"
{
  return QDEFAULT;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 156 "./fconfigl.l"
{
  return MATCHING;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 160 "./fconfigl.l"
{
  return ENUM;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 164 "./fconfigl.l"
{
  return MULTIENUMTOK;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 168 "./fconfigl.l"
{
  return ENUM_IN_FILE;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 172 "./fconfigl.l"
{
  return MULTI_ENUM_IN_FILE;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 176 "./fconfigl.l"
{
  return KEYTOK;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 180 "./fconfigl.l"
{
  return FIELDSTOK;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 184 "./fconfigl.l"
{
  return VALUES;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 188 "./fconfigl.l"
{
  return DEFAULT;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 192 "./fconfigl.l"
{
  return INPUTDEFAULTTOK;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 196 "./fconfigl.l"
{
  return EXACT_REGEXP;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 200 "./fconfigl.l"
{
  return INEXACT_REGEXP;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 204 "./fconfigl.l"
{
  return ALL;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 208 "./fconfigl.l"
{
  return FORMATTOK;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 212 "./fconfigl.l"
{
  return TEXTSEARCH;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 216 "./fconfigl.l"
{
  return QUERYTOK;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 220 "./fconfigl.l"
{
  return INDEXTOK;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 224 "./fconfigl.l"
{
  return SEPARATORTOK;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 228 "./fconfigl.l"
{
  return RESTRICTEDTOK;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 232 "./fconfigl.l"
{
  return INTEGERTOK;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 236 "./fconfigl.l"
{
  return NOSPACESTOK;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 240 "./fconfigl.l"
{
   return BUILTINTOK;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 244 "./fconfigl.l"
{
   return ALLOWANYVALUETOK;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 248 "./fconfigl.l"
{
   return CHANGETOK;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 252 "./fconfigl.l"
{
   return REQUIRETOK;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 256 "./fconfigl.l"
{
   return APPENDFIELDTOK;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 260 "./fconfigl.l"
{
   return SETFIELDTOK;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 264 "./fconfigl.l"
{
   return DESCRIPTIONTOK;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 268 "./fconfigl.l"
{
   return INPUTTOK;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 272 "./fconfigl.l"
{
    return DATABASEINFOTOK;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 276 "./fconfigl.l"
{
    return DEBUGMODETOK;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 280 "./fconfigl.l"
{
    return KEEPRECTOK;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 284 "./fconfigl.l"
{
    return NOTIFYEXPTOK;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 288 "./fconfigl.l"
{
    return SUBMITTERACKTOK;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 292 "./fconfigl.l"
{
    return LIBEXECDIRTOK;
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 296 "./fconfigl.l"
{
    return BUSINESSDAYTOK;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 300 "./fconfigl.l"
{
    return BUSINESSWEEKTOK;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 304 "./fconfigl.l"
{
    return CREATECATEGORYDIRSTOK;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 308 "./fconfigl.l"
{
    return FALSETOK;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 312 "./fconfigl.l"
{
    return TRUETOK;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 316 "./fconfigl.l"
{
    return ENUMSEPARATORSTOK;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 320 "./fconfigl.l"
{
    return MAILFORMATTOK;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 324 "./fconfigl.l"
{
    return TOADDRESSESTOK;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 328 "./fconfigl.l"
{
    return FROMADDRESSTOK;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 332 "./fconfigl.l"
{
    return REPLYTOTOK;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 336 "./fconfigl.l"
{
    return FIXEDTOK;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 340 "./fconfigl.l"
{
    return BODYTOK;
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 344 "./fconfigl.l"
{
    return HEADERTOK;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 348 "./fconfigl.l"
{
    return AUDITTRAILFMTTOK;
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 352 "./fconfigl.l"
{
    return ADDAUDITTRAILTOK;
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 356 "./fconfigl.l"
{
    return REQUIRECHANGEREASONTOK;
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 360 "./fconfigl.l"
{
    return READONLYTOK;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 364 "./fconfigl.l"
{
    return BINARYINDEXTOK;
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 368 "./fconfigl.l"
{
    return AUXFLAGSTOK;
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 372 "./fconfigl.l"
{
    return PRLISTTOK;
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 376 "./fconfigl.l"
{
    return MAXPRSTOK;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 380 "./fconfigl.l"
{
    return EDITONLYTOK;
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 384 "./fconfigl.l"
{
    return VIRTUALFORMATTOK;
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 388 "./fconfigl.l"
{
    return RAWTOK;
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 392 "./fconfigl.l"
{
    return CATPERMSTOK;
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 396 "./fconfigl.l"
{
    return '|';
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 400 "./fconfigl.l"
{
  return yytext[0];
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 404 "./fconfigl.l"
{
  BEGIN(QuoteLex);
}
	YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 408 "./fconfigl.l"
{ fconfig_lineno++; yymore (); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 409 "./fconfigl.l"
{ yymore (); }
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 410 "./fconfigl.l"
{
   fprintf (stderr, "Warning: unquoted newline within quoted string at line %d\n",
            fconfig_lineno);
   fconfig_lineno++;
   yymore ();
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 416 "./fconfigl.l"
{ yymore (); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 417 "./fconfigl.l"
{
   fconflval.qstr = lexQString (yytext);
   BEGIN (0);
   return QSTRING;
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 423 "./fconfigl.l"
/* A comment */
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 425 "./fconfigl.l"
{
   fconflval.intval = atoi (yytext);
   return INTVAL;
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 430 "./fconfigl.l"
{
   return '-';
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 434 "./fconfigl.l"
/* The usual "eat up whitespace" */
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 435 "./fconfigl.l"
{
   fconfig_lineno++;
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 439 "./fconfigl.l"
{
   BEGIN (BadTok);
   yymore ();
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 444 "./fconfigl.l"
{
   fprintf (stderr, "Unrecognized token %s at line %d\n", yytext,
            fconfig_lineno);
   BEGIN (0);
   return BADTOK;
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 450 "./fconfigl.l"
ECHO;
	YY_BREAK
#line 1751 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(BadTok):
case YY_STATE_EOF(QuoteLex):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 636 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 636 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 635);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yy_str )
{
    
	return yy_scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * bytes, int  len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 450 "./fconfigl.l"
